@@ -3,17 +3,18 @@
 # Make a DFSG version of upstream tarball
 # - remove all packaged JAR
 # - remove non-free VSD files (MS Visio)
+# - remove non-free MD4 in MD4.java
 # - remove generated Javadoc and Xref
 # - remove LICENCE.*.txt from other projects
 
 # $2 = version
 # $3 = file
-DIR=mina-$2.dfsg
-TAR=mina_$2.dfsg.orig.tar.gz
+DIR=mina2-$2.orig
+TAR=mina2_$2+dfsg.orig.tar.gz
 
 # clean up the upstream tarball
 tar zxf $3
-mv mina-$2 $DIR
+mv apache-mina-* $DIR
 GZIP=--best tar czf $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR
 
